#!/bin/bash

#Monitor the IRCamera battery. Exit (and be annoying) if it goes flat.
#Copyright (C) 2013 Richard Neill. This is Free Software, released under the GNU GPL v3+

if ! which beep >/dev/null; then 
	echo "The beep command isn't present, please install it"
	exit 1
fi

if [ $# != 0 -a "$1" != "-s" ]; then
	echo "This monitors the IR camera battery, and complains loudly if/when it goes flat. (It wraps 'filterctl -M')."
	echo "Run this in a spare terminal. It will print the battery status at all times, or yield to filter-positioning"
	echo "When the battery goes flat, it will show a dialog-box, beep in a pattern, and quit."
	echo ""
	echo "USAGE:    `basename $0 .sh`  [OPTIONS] "
	echo ""
	echo "OPTIONS:  -s       make just a single measurement and then exit (uses 'filterctl -b')"
	echo "          [none]   keep polling till battery goes flat."
	echo ""
	exit 1
fi

#Run filterctl -M. Prints constantly updating status.
#Ctrl-C (gracefully) kills the filterctl command, not this shell script.
if [ "$1" == "-s" ]; then
	filterctl -b
else
	echo "Monitoring battery..."
	filterctl -M
fi

#On exit, if trouble.
if [ $? != 0 ] ;then
	#Msg
	echo "Warning: the IR Camera system has a flat battery. Please swap/charge it NOW."
	echo "It may run for a short while longer, but then the data will be invalid."

	#Start dialog box in background. 
	zenity --error --title "IR Camera Battery" --text='The IR Camera has a Flat Battery.\nPlease Swap/Charge it NOW.\n\n[There is a few percent of life left, but data will soon be invalid.]' &

	#Beep (locally) in an annoying and recongnisable way
	beep -f 1000 -r 2 -n -r 5 -l 10 --new

	#Beep the terminal bell. (useful if we are on an SSH connection)
	echo -e "\a"; sleep 0.5; echo -e "\a"; sleep 0.5;  echo -e "\a"
fi

if [ "$1" != "-s" ]; then
	echo "Monitoring of battery has now stopped."
fi

exit 0
