#!/bin/bash
#This is to help set up the focus of the dewar optics.
#Copyright (C) 2013 Richard Neill. This is Free Software, released under the GNU GPL v3+

#Note that VLC is less good here than mplayer: it's far too noisy, and we must explicitly trap ctrl-C and kill-9 it, since it won't otherwise quit cleanly.
#Mplayer is much more well behaved. But for reference:
#VLC_CMD="vlc -q v4l2:///dev/video0 --noaudio"
#ctrl_c(){
#	killall -9 vlc
#}
#trap ctrl_c SIGINT

#Play video (this is even good enough over SSH/X11 when slowed down to 5fps.)
MPLAYER_CMD="mplayer -really-quiet -nolirc tv:// -tv driver=v4l2:noaudio:fps=5"

#Grab pictures. NB the first few have garbage/artefacts, so take the 10th frame.
MPLAYER_PHOTO_CMD="mplayer -really-quiet -nolirc tv:// -tv driver=v4l2:noaudio:fps=25 -vo jpeg -frames 10"

#Show picture. qiv is significantly quicker than xli.
VIEW_CMD="qiv 00000010.jpg"

if [ $# -ne 0 -a "$1" != "still" -a "$1" != "video" ]; then
	echo -e "\n"
	echo -e "The IR Camera is mounted inside a dewar. It's difficult to see when the optics are aligned,"
	echo -e "and until they are nearly focused, there is no way to get a good image. The alignment process is:"
	echo -e ""
	echo -e "1. Place the dummy chip in the dewar, and use the ircam_plcc84 script to shine light OUT of the dewar,"
	echo -e "   then adjust the focus to ensure that spots are formed on the plane of the lamp board. This is a good"
	echo -e "   initial setting, but the focal plane of the Hawaii chip isn't exactly the same place."
	echo -e ""
	echo -e "2. Put the bare MUX (or the real Hawaii chip) into the dewar. Shine the lamp board (or torch) onto it"
	echo -e "   through the lens with the same focus as before (control the lamp board with local switches, and with"
	echo -e "   ircam_serial_illuminate). Then, look at the plane of the chip through the dewar window, and try to"
	echo -e "   focus the spots. This is dangerous (placing one's head under a heavy dewar, and eye potentially in a"
	echo -e "   laser beam is unwise); also it's difficult to see easily. So we use a cheap USB webcam. Invoke this"
	echo -e "   script without -h to use VLC to display the webcam. (or run '$CMD'.)"
	echo -e ""
	echo -e "3. Now that the system is basically aligned, it should be possible to capture data and then display what"
	echo -e "   the Hawaii sensor actually sees (and then use beamfinder to get the exact pixels)."
	echo -e ""
	echo -e "This is also useful for remotely checking that state of illumination of the sensor. The 'torch' illumination is"
	echo -e "easy to see; the LED illumination is faint but discernible. See: ircam_serial_illuminate."
	echo -e ""
	echo -e "USAGE: invoke with no arguments for video, or 'still' for a single picture."
	echo -e ""
	exit 1
fi

if [ -z "$1" -o "$1" == video ];then
	
	#Video
	echo "Now running command: $MPLAYER_CMD"
	$MPLAYER_CMD

else

	#Still Image 
	#Create a temporary directory, save 10 photos, open one of them and delete the rest.
	TEMP_DIR=$(mktemp -d -t hawaii_char.XXXXXXX);
	pushd $TEMP_DIR >/dev/null 2>&1

	echo "Now running command: $MPLAYER_PHOTO_CMD"
	$MPLAYER_PHOTO_CMD 2>/dev/null
	$VIEW_CMD

	popd >/dev/null 2>&1
	rm -r $TEMP_DIR
	
fi

